@@ -1,6 +1,6 @@
 # fields  is a package for analysis of spatial data written for
 # the R software environment .
-# Copyright (C) 2017
+# Copyright (C) 2018
 # University Corporation for Atmospheric Research (UCAR)
 # Contact: Douglas Nychka, nychka@ucar.edu,
 # National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
@@ -233,6 +233,9 @@
     if (!out$fixed.model) {
         if (out$knot.model) {
             # the knot model engine
+            if( verbose){
+              cat("called Krig.engine.knots: ", fill=TRUE)
+            }
             out$matrices <- Krig.engine.knots(out, verbose = verbose)
             out$pure.ss <- out$matrices$pure.ss
         }
@@ -270,7 +273,7 @@
     #########################
     #################################################
     # Do GCV and REML search over lambda if not fixed or if GCV variable is TRUE
-    # gcv.Krig, not named well,  also does a search over likelihood for lambda.
+    # gcv.Krig is not named well,  also does a search over likelihood for lambda.
     #################################################
     if (!out$fixed.model | out$GCV) {
         if (verbose) {
@@ -364,12 +367,6 @@
     return(out)
 }
 
-
-# fields, Tools for spatial data
-# Copyright 2015, Institute for Mathematics Applied Geosciences
-# University Corporation for Atmospheric Research
-# Licensed under the GPL -- www.gpl.org/licenses/gpl.html
-
 Krig.check.xY <- function(x, Y, Z, weights, na.rm, 
     verbose = FALSE) {
     #
@@ -698,7 +695,7 @@ Krig.Amatrix <- function(object, x0 = object$x, lambda = NULL,
     #   Solving
     #   beta2 = {Q.2^T K Q.2 + lambda I )^ {-1} Q.2^T yM
     #
-    # and so one sloves this linear system for beta2 and then uses
+    # and so one solves this linear system for beta2 and then uses
     #     c= Q.2 beta2
     #   to determine c.
     #
@@ -952,6 +949,10 @@ Krig.Amatrix <- function(object, x0 = object$x, lambda = NULL,
     H[(nt + 1):np, (nt + 1):np] <- do.call(out$cov.function.name, 
         c(out$args, list(x1 = out$knots, x2 = out$knots)))
     # X is the monster ...
+    if( verbose){
+      print( out$cov.function.name)
+      print( out$args)
+    }
     X <- cbind(do.call(out$null.function.name, c(out$null.args, 
         list(x = out$xM, Z = out$ZM))), do.call(out$cov.function.name, 
         c(out$args, list(x1 = out$xM, x2 = out$knots))))
@@ -1210,7 +1211,7 @@ Krig.null.function <- function(x, Z = NULL, drop.Z = FALSE,
     }
 }
 
-"Krig.parameters" <- function(obj, mle.calc = obj$mle.calc) {
+Krig.parameters <- function(obj, mle.calc = obj$mle.calc) {
     # if nondiag W is supplied then use it.
     # otherwise assume a diagonal set of weights.
     #
@@ -1248,11 +1249,12 @@ Krig.null.function <- function(x, Z = NULL, drop.Z = FALSE,
 }
 
 "Krig.replicates" <- function(out=NULL, x,y, Z=NULL, weights=rep( 1, length(y)),
+                               digits=8,
                                verbose = FALSE) {
     if( is.null(out)){
       out<- list( x=x, y=y, N= length(y), Z=Z, weights=weights)
     }
-    rep.info <- cat.matrix(out$x)
+    rep.info <- cat.matrix(out$x, digits=digits)
     if (verbose) {
         cat("replication info", fill = TRUE)
         print(rep.info)
